<?php

function post($name, $default = '') {
    return isset($_POST[$name]) ? htmlspecialchars($_POST[$name]) : $default;
}

// Euclidean n dimensional distance.
function distance2D($p, $q)
{
    return sqrt(pow($p[0] - $q[0], 2) + pow($p[1] - $q[1], 2));
}

function apollonius($points)
{
    $A = $points[0];
    $B = $points[1];
    $C = $points[2];
    $a = distance2D($C, $B);
    $b = distance2D($C, $A);
    $c = distance2D($B, $A);
    $s = ($a + $b + $c) / 2.;
    $R = $a * $b * $c / 4. / sqrt($s * ($s - $a) * ($s - $b) * ($s - $c));
    $b1 = $a*$a * ($b*$b + $c*$c - $a*$a);
    $b2 = $b*$b * ($a*$a + $c*$c - $b*$b);
    $b3 = $c*$c * ($a*$a + $b*$b - $c*$c);
    $P = array(
        ($A[0] * $b1 + $B[0] * $b2 + $C[0] * $b3) / ($b1 + $b2 + $b3),
        ($A[1] * $b1 + $B[1] * $b2 + $C[1] * $b3) / ($b1 + $b2 + $b3),
        ($A[2] * $b1 + $B[2] * $b2 + $C[2] * $b3) / ($b1 + $b2 + $b3)
    );
    return array($R, $P);
}

$result = '';

if (post('calculate'))
{
    $a = preg_split('/[\t\s,]+/', post('a', '0 0'));
    $b = preg_split('/[\t\s,]+/', post('b', '0 0'));
    $c = preg_split('/[\t\s,]+/', post('c', '0 0'));

    $o = apollonius(array(
        array(floatval($a[0]), floatval($a[1]), 0),
        array(floatval($b[0]), floatval($b[1]), 0),
        array(floatval($c[0]), floatval($c[1]), 0)
    ));

    $result = sprintf("Mittelpunkt: %.3f, %.3f\nRadius: %.3f", $o[1][0], $o[1][1], $o[0]);
}

?><!DOCTYPE html>
<head>
</head>
<body>

  <form action="./apollonius.php" method="post" enctype="multipart/form-data">
   <fieldset>
    <legend>Kreismittelpunkt und Radius mit drei Punkten finden (<a href="https://de.wikipedia.org/wiki/Apollonisches_Problem">Apollonisches Problem</a>)</legend>
    <div>
      <label for="a">P1 (X, Y):</label>
      <input style="width: 300px;" name="a" type="text" value="<?=post('a', '0 0')?>" required>
    </div>
    <div>
      <label for="b">P2 (X, Y):</label>
      <input style="width: 300px;" name="b" type="text" value="<?=post('b', '0 0')?>" required>
    </div>
    <div>
      <label for="c">P3 (X, Y):</label>
      <input style="width: 300px;" name="c" type="text" value="<?=post('c', '0 0')?>" required>
    </div>
    <div>
        <input name="calculate" type="submit" value="Berechnen">
    </div>
   </fieldset>
  </form>

  <fieldset>
    <legend>Ergebnis</legend>
    <pre><?=$result?></pre>
  </fieldset>

</body>
</html>
