<?php defined("CYCLONE") or die();

/**
 * Cyclone - Cylindrical projection tool for photogrammetry.
 * Copyright (C) 2015  Bernhard Arnold <bernhard.arnold@burgried.at>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

//
// 2-D point container class.
//

class Point2D {
    public function __construct($x = 0.0, $y = 0.0) {
        $this->set($x, $y);
    }
    public function set($x, $y) {
        $this->x_ = floatval($x);
        $this->y_ = floatval($y);
    }
    public function x() {
        return $this->x_;
    }
    public function y() {
        return $this->y_;
    }
    public function deltaXY($p) {
        // Returns absolute dx and dy of two points.
        return array(abs($this->x() - $p->x()), abs($this->y() - $p->y()));
    }
    public static function fromString($str) {
        $tokens = preg_split('/[\t\s,]+/', $str);
        if (sizeof($tokens) != 2)
            throw new Exception("Not a valid 2D point");
        return new Point2D($tokens[0], $tokens[1]);
    }
    public function __toString() {
        return sprintf("%.3f %.3f", $this->x(), $this->y());
    }
    private $x_, $y_;
}

//
// 3-D point container class.
//

class Point3D extends Point2D {
    public function __construct($x = 0.0, $y = 0.0, $z = 0.0) {
        $this->set($x, $y, $z);
    }
    public function set($x, $y, $z) {
        parent::set($x, $y);
        $this->z_ = floatval($z);
    }
    public function z() {
        return $this->z_;
    }
    public static function fromString($str) {
        $tokens = preg_split('/[\t\s,]+/', $str);
        if (sizeof($tokens) != 3)
            throw new Exception("Not a valid 3D point");
        return new Point3D($tokens[0], $tokens[1], $tokens[2]);
    }
    public function __toString() {
        return sprintf("%.3f %.3f %.3f", $this->x(), $this->y(), $this->z());
    }
    private $z_;
}

//
// ArchServ 3-D point container class.
//

class ArchServPoint extends Point3D {
    public function __construct($name, $x, $y, $z, $code = "") {
        $this->set($name, $x, $y, $z, $code);
    }
    public function set($name, $x, $y, $z, $code = "") {
        $this->name_ = $name;
        parent::set($x, $y, $z);
        $this->code_ = $code;
    }
    public function name() {
        return $this->name_;
    }
    public function code() {
        return $this->code_;
    }
    public function isHelper() {
        preg_match($this->pattern_, $this->name(), $matches);
        return sizeof($matches) == 0;
    }
    public function decode() {
        preg_match($this->pattern_, $this->name(), $matches);
        if (sizeof($matches) == 5)
            return array(intval($matches[1]), $matches[2], intval($matches[3]), intval($matches[4]));
        return $this->name();
    }
    public static function fromString($str) {
        $tokens = preg_split('/[\t\s]+/', $str);
        if (sizeof($tokens) < 4)
            throw new Exception("Not a valid ArchServ point");
        return new ArchServPoint($tokens[0], $tokens[1], $tokens[2], $tokens[3], sizeof($tokens) > 4 ? $tokens[4] : "");
    }
    public function __toString() {
        return sprintf("%s\t\t%.3f\t%.3f\t%.3f\t%s", $this->name(), $this->x(), $this->y(), $this->z(), $this->code());
    }
    private $pattern_ = '/^([0-9]{4})([A-Z])([0-9]{2})([0-9]{3})/';
    private $name_;
    private $code_;
}
