<?php defined("CYCLONE") or die();

/**
 * Cyclone - Cylindrical projection tool for photogrammetry.
 * Copyright (C) 2015  Bernhard Arnold <bernhard.arnold@burgried.at>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

?><!DOCTYPE html>
<html lang="de">
<head>
  <meta charset="utf-8">
  <title>Zylinderprojektion für Photogrammetrie</title>
  <style>
    label {
      display: block;
      float: left;
      width: 10em;
    }
    pre {
      font-size: 12px;
    }
    p.error {
      background-color: #ff8080;
    }
  </style>
</head>
<body>

<h1>Zylinderprojektion <sub><em> &nbsp;für Photogrammetrie</em></sub></h1>

<hr>

<?=$errors?>

  <p><img style="float:right;" src="static/images/zylinderprojektion.png" alt="Prinzip der Zylinderprojektion">Zylinderprojektion für runde Objekte: Für die Projektion wird das Zentrum und der Radius des Zylinders angegeben auf den alle Punkte im Raum projeziert werden. Punkte müssen sich nicht zwingend exakt auf der Zylinderfläche befinden. Liegt ein Punkt hinter oder vor der Projektionsebene so wird er darauf projeziert. <em>Ursprung</em> ist die X,Y Position des Mittelpunkts, <em>Radius</em> der Radius der Zylinderprojektion. Die Abwicklung läuft immer gegen den Uhrzeigersinn, der erste Punkt (<em>Start</em>) ist anzugeben. Als Punkte werden Messpunkte im ArchServ oder XYZ Format akzeptiert. Die Höhe der transformierten Punkte bleibt unverändert und wird als Y Koordinate wiedergegeben. Die X Koordinate beginnt bei 0 und entspricht dem exakten Kreisbogenabstand auf der Projektionsebene (abgerollt).</p>

  <p><a href="./static/apollonius.php">Kreismittelpunkt und Radius berechnen</a> (drei Punkte notwendig, am besten über 180&deg; verteilt).</p>

  <form action="." method="post" enctype="multipart/form-data">
    <fieldset>
      <legend>Zylinderprojektion (Rundtürme, Apsiden)</legend>

      <div>
        <label for="center">Ursprung (X, Y):</label>
        <input style="width: 300px;" name="center" type="text" value="<?=$center?>" required>
      </div>
      <div>
        <label for="radius">Radius [m]:</label>
        <input style="width: 300px;" name="radius" type="text" value="<?=$radius?>" required>
      </div>
      <div>
        <label for="start">Start (X, Y):</label>
        <input style="width: 300px;" name="start" type="text" value="<?=$start?>">
      </div>
      <div>
        <label for="points">Punkte (ArchServ):</label>
        <textarea style="width: 600px;" name="points" rows="10" required><?=$points?></textarea>
      </div>
      <div>
        <label for="format">Ausgabeformat:</label>
        <select name="format">
          <option value="wkt" <?=($format == "wkt") ? "selected" : "" ?>>WKT</option>
          <option value="csv" <?=($format == "csv") ? "selected" : "" ?>>CSV</option>
          <option value="json" <?=($format == "json") ? "selected" : "" ?>>JSON</option>
        </select>
      </div>
      <div>
        <input name="calculate" type="submit" value="Berechnen">
        <input name="clear" type="submit" value="Löschen">
      </div>
    </fieldset>
  </form>

  <fieldset style="float: right; max-width: 350px;">
    <legend>Protokoll</legend>
    <pre>Ursprung (X,Y): <?=$c_center?></pre>
    <pre>Radius: <?=$c_radius?> m</pre>
    <pre>Zylinderumfang: <?=$c_extent?> m</pre>
    <pre>Offset: <?=$c_offset?> m (<?=$c_start?>)</pre>
  </fieldset>

  <fieldset>
    <legend>Ergebnis</legend>
    <pre><?=$result?></pre>
  </fieldset>

  <div id="footer" style="color: #888; clear: both;">
    <p><em>Cyclone</em> ist eine freie, unter der <a href="http://www.gnu.org/licenses/gpl-3.0.txt">GNU/GPL-Lizenz 3.0</a> veröffentlichte Software.<br>
    Version <?=__version__?> - source tarball is available to <a href="cyclone-<?=__version__?>.tar.gz">download</a> here.<br>
    Copyright &copy; 2015 Bernhard Arnold</p>
  </div>

</body>
</html>
